@@ -186,6 +186,7 @@ class Rakuten:
         wait = WebDriverWait(self.driver, default_wait)
         self.transition_global_menu(GlobalMenu.KASHIKABU, default_wait)
         wait.until(EC.presence_of_element_located((By.LINK_TEXT, "貸株金利"))).click()
+        wait.until(EC.presence_of_element_located((By.CLASS_NAME, "tab1"))).click()
         # download csv
         session_id = self.get_session_id()
         download_path = f"{path}/rakuten_kashikabu_rate.csv"
@@ -215,11 +216,9 @@ class Rakuten:
 
         logger.info(f"rakuten kashikabu rate, from: {from_date}, to: {to_date}")
         if to_date > from_date:
+            # TBD: 年跨ぎの処理
             formated_from_date = datetime.strptime(f"{today.year}/{from_date}", '%Y/%m/%d')
             formated_to_date = datetime.strptime(f"{today.year}/{to_date}", '%Y/%m/%d') - timedelta(days=1)
-            #df_from = df.assign(date=formated_from_date)
-            #df_to = df.assign(date=formated_to_date)
-            #df = pd.concat([df_from, df_to])
             df["from_date"] = formated_from_date
             df["to_date"] = formated_to_date
             df["next_from_date"] = formated_to_date + timedelta(days=1)
@@ -232,6 +231,10 @@ class Rakuten:
             df = df.rename(columns={columns[5]: 'next_trust_interest_rate'})
             df = df.rename(columns={columns[6]: 'non_target_period'}) # 非対象期間
             df = df.rename(columns={columns[7]: 'description'}) # 摘要
+            df = df.query('interest_rate != "-"')
+            df = df.query('next_interest_rate != "-"')
+            df = df.query('trust_interest_rate != "-"')
+            df = df.query('next_trust_interest_rate != "-"')
             df["interest_rate"] = df["interest_rate"].str.replace('%', '').astype(float) * 0.01
             df["next_interest_rate"] = df["next_interest_rate"].str.replace('%', '').astype(float) * 0.01
             df["trust_interest_rate"] = df["trust_interest_rate"].str.replace('%', '').astype(float) * 0.01
@@ -252,9 +255,9 @@ class Rakuten:
                 r = pd.date_range(start=df_code.from_date.min(), end=df_code.next_to_date.max())
                 df_continuous = df_code.set_index('from_date').reindex(r).fillna(method='ffill').rename_axis('from_date').reset_index()
                 # 今回、次回貸株金利を反映
-                df_current = df_continuous.query('from_date < to_date').copy()
+                df_current = df_continuous.query('from_date <= to_date').copy()
                 df_current["target_date"] = df_current["from_date"]
-                df_next = df_continuous.query('from_date >= to_date').copy()
+                df_next = df_continuous.query('from_date > to_date').copy()
                 df_next["target_date"] = df_next["from_date"]
                 df_next["interest_rate"] = df_next["next_interest_rate"]
                 df_next["trust_interest_rate"] = df_next["next_trust_interest_rate"]
